@@ -30,6 +30,7 @@ class Sniper:
         self.options.logger.verbose(f"Calibration baseline for {insertion_point}")
 
         sleep_time = self.options.args.calibration_sleep/1000 or self.options.args.sleep/1000
+        payload= ''.join(random.choices(string.ascii_uppercase + string.digits, k=random.randint(10,20))) # Generating in case num_calibrations is 0
         for i in range(self.options.args.num_calibrations):
             payload= ''.join(random.choices(string.ascii_uppercase + string.digits, k=random.randint(10,20)))
             time.sleep(sleep_time)
@@ -111,11 +112,10 @@ class Sniper:
             
         diffs_sections={}
         if checks >= self.options.args.num_verifications:
-            if self.options.args.verbose:
-                for i in diffs:
-                    if i["section"] not in diffs_sections.keys():
-                        diffs_sections[i["section"]] = 0
-                    diffs_sections[i["section"]] += len(i["diffs"])
+            for i in diffs:
+                if i["section"] not in diffs_sections.keys():
+                    diffs_sections[i["section"]] = 0
+                diffs_sections[i["section"]] += len(i["diffs"])
 
             self.options.logger.debug(f"Diffs:\n{str(diffs)}\n")
             payload1 = insertion1.payload
